@@ -15,6 +15,7 @@ import (
 func TestParser_Compile(t *testing.T) {
 	tests := []struct {
 		name string
+		data map[string]interface{}
 	}{
 		{
 			name: "different env dirs",
@@ -22,6 +23,9 @@ func TestParser_Compile(t *testing.T) {
 		{
 			name: "different env files",
 		},
+		{
+			name: "external dirs",
+		},
 		{
 			name: "include directory based on file",
 		},
@@ -31,6 +35,12 @@ func TestParser_Compile(t *testing.T) {
 		{
 			name: "with string manipulation functions",
 		},
+		{
+			name: "with top level template data",
+			data: map[string]interface{}{
+				"branch": "test",
+			},
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -41,7 +51,7 @@ func TestParser_Compile(t *testing.T) {
 			f, err := os.Open(golden)
 			require.NoError(t, err)
 
-			p := NewParser(testDataPath)
+			p := NewParser(testDataPath, tt.data)
 
 			wr := &bytes.Buffer{}
 			err = p.CompileFromFile(input, wr)
