@@ -11,6 +11,10 @@ func GetDefaultRefIDFunc(d *schema.ResourceData) []string {
 	return []string{d.Get("id").String()}
 }
 
+func DefaultCloudResourceIDFunc(d *schema.ResourceData) []string {
+	return []string{}
+}
+
 func GetSpecialContext(d *schema.ResourceData) map[string]interface{} {
 	return map[string]interface{}{}
 }
